@@ -7,6 +7,8 @@ from core_module_text_area_app.views.views import TextAreaModule
 
 urlpatterns = [
     re_path(
-        r"module-text-area", TextAreaModule.as_view(), name="core_module_text_area_view"
+        r"module-text-area",
+        TextAreaModule.as_view(),
+        name="core_module_text_area_view",
     ),
 ]
