@@ -4,7 +4,10 @@ import re
 
 from django.template import loader
 
-from core_module_text_area_app.settings import AUTO_ESCAPE_XML_ENTITIES
+from core_module_text_area_app.settings import (
+    AUTO_ESCAPE_XML_ENTITIES,
+    ENABLE_XML_ENTITIES_TOOLTIPS,
+)
 from core_parser_app.tools.modules.views.builtin.textarea_module import (
     AbstractTextAreaModule,
 )
@@ -12,6 +15,8 @@ from xml_utils.xsd_tree.operations.xml_entities import XmlEntities
 
 
 class TextAreaModule(AbstractTextAreaModule):
+    """Text Area Module"""
+
     def _retrieve_data(self, request):
         """Retrieve module's data
 
@@ -48,14 +53,22 @@ class TextAreaModule(AbstractTextAreaModule):
         Returns:
 
         """
-        # search the XML predefined entities, to display warning if it needed / we add pre escaped search too
+        # if tooltips are disabled, return empty message
+        if not ENABLE_XML_ENTITIES_TOOLTIPS:
+            return ""
+
+        # search the XML predefined entities, to display warning if needed / we add pre escaped search too
         if (
             self.data_xml_entities.number_of_subs_made > 0
-            or len(re.findall(r"((&amp;)|(&gt;)|(&lt;)|(&apos;)|(&quot;))", self.data))
+            or len(
+                re.findall(
+                    r"((&amp;)|(&gt;)|(&lt;)|(&apos;)|(&quot;))", self.data
+                )
+            )
             > 0
         ):
             return loader.get_template(
                 "core_module_text_area_app/predefined_entities_warning.html"
             ).template.source
-        else:
-            return ""
+
+        return ""
